@@ -1,5 +1,5 @@
 package Log::Any::App;
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 # ABSTRACT: A simple wrapper for Log::Any + Log::Log4perl for use in applications
 
 
@@ -470,7 +470,7 @@ sub _find_level {
             }
         }
         for (@label2level) {
-            if ($ENV{$key = $P_ . $_->[0]}) {
+            if ($ENV{$key = $P_ . uc($_->[0])}) {
                 $level = $_->[1];
                 $from = "\$ENV{$key}";
                 last FIND;
@@ -544,10 +544,11 @@ Log::Any::App - A simple wrapper for Log::Any + Log::Log4perl for use in applica
 
 =head1 VERSION
 
-version 0.04
+version 0.06
 
 =head1 SYNOPSIS
 
+
     # in your script/application
     use Log::Any::App qw($log);
 
@@ -556,19 +557,24 @@ version 0.04
 
 =head1 DESCRIPTION
 
+
 L<Log::Any> makes life easy for module authors. All you need to do is:
 
+
  use Log::Any qw($log);
 
+
 and you're off logging with $log->debug(), $log->info(),
 $log->error(), etc. That's it. The task of initializing and
 configuring the logger rests on the shoulder of module users.
 
+
 It's less straightforward for module users though, especially for
 casual ones. You have to pick an adapter and connect it to another
 logging framework (like L<Log::Log4perl>) and configure it. The
 typical incantation is like this:
 
+
  use Log::Any qw($log);
  use Log::Any::Adapter;
  use Log::Log4perl;
@@ -580,154 +586,208 @@ typical incantation is like this:
  Log::Log4perl->init(\$log4perl_config);
  Log::Any::Adapter->set('Log4perl');
 
+
 Frankly, I couldn't possibly remember all that (especially the details
 of Log4perl configuration), hence Log::Any::App. The goal of
 Log::Any::App is to make life equally easy for application authors and
 module users. All you need to do is:
 
+
  use Log::Any::App qw($log);
 
+
 or, from the command line:
 
+
  perl -MLog::Any::App='$log' -MModuleThatUsesLogAny -e ...
 
+
 and you can display the logs in screen, file(s), syslog, etc. You can
 also log using $log->debug(), etc as usual. Most of the time you don't
 need to configure anything as Log::Any::App will construct the most
 appropriate default Log4perl config for your application.
 
+
 I mostly use Log::Any;:App in scripts and one-liners whenever there
 are Log::Any-using modules involved (like L<Data::Schema> or
 L<Config::Tree>).
 
 =head1 USING
 
+
 Most of the time you just need to do this from command line:
 
+
  % perl -MLog::Any::App -MModuleThatUsesLogAny -e ...
 
+
 or from a script:
 
+
  use Log::Any::App qw($log);
 
+
 this will send logs to screen as well as file (~/$NAME.log or
 /var/log/$NAME.log if running as root). One-liners by default do not
 log to file. $NAME will be taken from $0, but can be changed using:
 
+
  use Log::Any::App '$log', -name => 'myprog';
 
+
 Default level is 'warn', but can be changed in several ways. From the
 code:
 
+
  use Log::Any::App '$log', -level => 'debug';
 
+
 or:
 
+
  use Log::Any::App '$log';
  BEGIN {
      $Log_Level = 'fatal'; # setting to fatal
-     # $Debug = 1;         # another way, setting to debug
-     # $Verbose = 1;       # another way, setting to info
      # $Quiet = 1;         # another way, setting to error
+     # $Log_Level= 'warn'; # setting to warn, default
+     # $Verbose = 1;       # another way, setting to info
+     # $Debug = 1;         # another way, setting to debug
+     # $Trace = 1;         # another way, setting to trace
  }
 
+
 or from environment variable:
 
+
  LOG_LEVEL=fatal yourprogram.pl;   # setting level to fatal
- DEBUG=1 yourprogram.pl;           # setting level to debug
- VERBOSE=1 yourprogram.pl;         # setting level to info
- QUIET=1 yourproogram.pl;          # setting level to error
+ QUIET=1 yourproogram.pl;          # another way, setting to error
+ LOG_LEVEL=warn yourprogram.pl;    # setting level to warn, default
+ VERBOSE=1 yourprogram.pl;         # another way, setting to info
+ DEBUG=1 yourprogram.pl;           # another way, setting to debug
+ TRACE=1 yourprogram.pl;           # another way, setting to trace
+
 
 or, from the command line options:
 
+
  yourprogram.pl --log-level debug
  yourprogram.pl --debug
  # and so on
 
+
 If you want to add a second file with a different level and category:
 
+
  use Log::Any::App '$log', -file => ['first.log',
                                      {path=>'second.log', level=>'debug',
                                       category=>'Some::Category'}];
 
+
 If you want to turn off screen logging:
 
+
  use Log::Any::App -screen => 0;
 
+
 Logging to syslog is enabled by default if your script looks like a
 daemon, e.g.:
 
+
  use Net::Daemon; # this indicate your program is a daemon
  use Log::Any::App; # syslog logging will be turned on by default
 
+
 but if you don't want syslog logging:
 
+
  use Log::Any::App -syslog => 0;
 
+
 For all the available options, see the init() function.
 
 =head1 FUNCTIONS
 
+
 =head2 init(\@args)
 
+
 This is the actual function that implements the setup and
 configuration of logging. You normally need not call this function
 explicitly, it will be called once in a CHECK block. In fact, when you
 do:
 
+
  use Log::Any::App 'a', 'b', 'c';
 
+
 it is actually passed as:
 
+
  init(['a', 'b', 'c']);
 
+
 Arguments to init can be one or more of:
 
+
 =over 4
 
+
 =item -init => BOOL
 
+
 Default is true. You can set this to false, and you can initialize
 Log4perl yourself (but then there's not much point in using this
 module, right?)
 
+
 =item -name => STRING
 
+
 Change the program name. Default is taken from $0.
 
+
 =item -level => 'debug'|'warn'|...
 
+
 Specify log level for all outputs, e.g. C<warn>, C<debug>, etc. Each
 output can override this value. The default log level is determined as
 follow:
 
+
 If L<App::Options> is present, these keys are checked in
 B<%App::options>: B<log_level>, B<trace> (if true then level is
 C<trace>), B<debug> (if true then level is C<debug>), B<verbose> (if
 true then level is C<info>), B<quiet> (if true then level is
 C<error>).
 
+
 Otherwise, it will try to scrape @ARGV for the presence of
 B<--log-level>, B<--trace>, B<--debug>, B<--verbose>, or B<--quiet>
 (this usually works because Log::Any::App does this in the CHECK
 phase, before you call L<Getopt::Long>'s GetOptions() or the like).
 
+
 Otherwise, it will look for environment variables: B<LOG_LEVEL>,
-B<TRACE>, B<DEBUG>, B<VERBOSE>, B<QUIET>.
+B<QUIET>. B<VERBOSE>, B<DEBUG>, B<TRACE>.
+
 
 Otherwise, it will try to search for package variables in the C<main>
 namespace with names like C<$Log_Level> or C<$LOG_LEVEL> or
-C<$log_level>, C<$Trace> or C<$TRACE> or C<$trace>, C<$Debug> or
-C<$DEBUG> or C<$debug>, C<$Verbose> or C<$VERBOSE> or C<$verbose>,
-C<$Quiet> or C<$QUIET> or C<$quiet>.
+C<$log_level>, C<$Quiet> or C<$QUIET> or C<$quiet>, C<$Verbose> or
+C<$VERBOSE> or C<$verbose>, C<$Trace> or C<$TRACE> or C<$trace>,
+C<$Debug> or C<$DEBUG> or C<$debug>.
+
 
 If everything fails, it defaults to 'warn'.
 
+
 =item -file => 0 | 1|yes|true | PATH | {opts} | [{opts}, ...]
 
+
 Specify output to one or more files, using
 L<Log::Dispatch::FileRotate>.
 
+
 If the argument is a false boolean value, file logging will be turned
 off. If argument is a true value that matches /^(1|yes|true)$/i, file
 logging will be turned on with default path, etc. If the argument is
@@ -738,33 +798,42 @@ unlimited or never rotate), C<histories> (number of old files to keep,
 excluding the current file), C<category>, C<pattern> (Log4perl
 pattern).
 
+
 If the argument is an arrayref, it is assumed to be specifying
 multiple files, with each element of the array as a hashref.
 
+
 How Log::Any::App determines defaults for file logging:
 
+
 If program is a one-liner script specified using "perl -e", the
 default is no file logging. Otherwise file logging is turned on.
 
+
 If the program runs as root, the default path is
 C</var/log/$NAME.log>, where $NAME is taken from B<$0> (or
 C<-name>). Otherwise the default path is ~/$NAME.log. Intermediate
 directories will be made with L<File::Path>.
 
+
 Default rotating behaviour is no rotate (max_size = 0).
 
+
 Default level for file is the same as the global level set by
 B<-level>. But App::options, command line, environment, and package
 variables in main are also searched first (for B<FILE_LOG_LEVEL>,
 B<FILE_TRACE>, B<FILE_DEBUG>, B<FILE_VERBOSE>, B<FILE_QUIET>, and the
 similars).
 
+
 =item -dir => 0 | 1|yes|true | PATH | {opts} | [{opts}, ...]
 
+
 Log messages using L<Log::Dispatch::Dir>. Each message is logged into
 separate files in the directory. Useful for dumping content
 (e.g. HTML, network dumps, or temporary results).
 
+
 If the argument is a false boolean value, dir logging will be turned
 off. If argument is a true value that matches /^(1|yes|true)$/i, dir
 logging will be turned on with defaults path, etc. If the argument is
@@ -777,32 +846,41 @@ unlimited). C<histories> (number of old files to keep, excluding the
 current file), C<category>, C<pattern> (Log4perl pattern),
 C<filename_pattern> (pattern of file name).
 
+
 If the argument is an arrayref, it is assumed to be specifying
 multiple directories, with each element of the array as a hashref.
 
+
 How Log::Any::App determines defaults for dir logging:
 
+
 Directory logging is by default turned off. You have to explicitly
 turn it on.
 
+
 If the program runs as root, the default path is C</var/log/$NAME/>,
 where $NAME is taken from B<$0>. Otherwise the default path is
 ~/log/$NAME/. Intermediate directories will be created with
 File::Path. Program name can be changed using C<-name>.
 
+
 Default rotating parameters are: histories=1000, max_size=0,
 max_age=undef.
 
+
 Default level for dir logging is the same as the global level set by
 B<-level>. But App::options, command line, environment, and package
 variables in main are also searched first (for B<DIR_LOG_LEVEL>,
 B<DIR_TRACE>, B<DIR_DEBUG>, B<DIR_VERBOSE>, B<DIR_QUIET>, and the
 similars).
 
+
 =item -screen => 0 | 1|yes|true | {opts}
 
+
 Log messages using L<Log::Log4perl::Appender::ScreenColoredLevels>.
 
+
 If the argument is a false boolean value, screen logging will be
 turned off. If argument is a true value that matches
 /^(1|yes|true)$/i, screen logging will be turned on with default
@@ -811,20 +889,26 @@ must be one of: C<color> (default is true, set to 0 to turn off
 color), C<stderr> (default is true, set to 0 to log to stdout
 instead), C<level>, C<category>, C<pattern> (Log4perl string pattern).
 
+
 How Log::Any::App determines defaults for screen logging:
 
+
 Screen logging is turned on by default.
 
+
 Default level for screen logging is the same as the global level set
 by B<-level>. But App::options, command line, environment, and package
 variables in main are also searched first (for B<SCREEN_LOG_LEVEL>,
 B<SCREEN_TRACE>, B<SCREEN_DEBUG>, B<SCREEN_VERBOSE>, B<SCREEN_QUIET>,
 and the similars).
 
+
 =item -syslog => 0 | 1|yes|true | {opts}
 
+
 Log messages using L<Log::Dispatch::Syslog>.
 
+
 If the argument is a false boolean value, syslog logging will be
 turned off. If argument is a true value that matches
 /^(1|yes|true)$/i, syslog logging will be turned on with default
@@ -832,93 +916,121 @@ level, ident, etc. If the argument is a hashref, then the keys of the
 hashref must be one of: C<level>, C<ident>, C<facility>, C<category>,
 C<pattern> (Log4perl pattern).
 
+
 How Log::Any::App determines defaults for syslog logging:
 
+
 If a program is a daemon (determined by detecting modules like
 L<Net::Server> or L<Proc::PID::File>) then syslog logging is turned on
 by default and facility is set to C<daemon>, otherwise the default is
 off.
 
+
 Ident is program's name by default ($0, or C<-name>).
 
+
 Default level for syslog logging is the same as the global level set
 by B<-level>. But App::options, command line, environment, and package
 variables in main are also searched first (for B<SYSLOG_LOG_LEVEL>,
 B<SYSLOG_TRACE>, B<SYSLOG_DEBUG>, B<SYSLOG_VERBOSE>, B<SYSLOG_QUIET>,
 and the similars).
 
+
 =item -dump => BOOL
 
+
 If set to true then Log::Any::App will dump the generated Log4perl
 config. Useful for debugging the logging.
 
+
 =back
 
 =head1 FAQ
 
+
 =head2 What's the benefit of using Log::Any::App?
 
+
 All of Log::Any and all of Log::Log4perl, as what Log::Any::App does
 is just combine those two (and add a thin wrapper). You still produce
 log with Log::Any so later should portions of your application code
 get refactored into modules, you don't need to change the logging
 part.
 
+
 =head2 Do I need Log::Any::App if I am writing modules?
 
+
 No, if you write modules just use Log::Any.
 
+
 =head2 Why Log4perl instead of Log::Dispatch?
 
+
 You can use Log::Dispatch::* output modules in Log4perl but
 (currently) not vice versa.
 
+
 You can configure Log4perl using a configuration file, so you can
 conveniently store your settings separate from the application.
 
+
 Feel free to fork Log::Any::App and use Log::Dispatch instead if you
 don't like Log4perl.
 
+
 =head2 Why not just use Log4perl then? Why bother with Log::Any at all? You're tied to Log4perl anyway.
 
+
 Yes, combining Log::Any with Log4perl (or some other adapter) is
 necessary to get output, but that's only in applications. Your
 Log::Any-using modules are still not tied to any adapter.
 
+
 The goal is to keep using Log::Any in your modules, and have a
 convenient way of displaying your logs in your applications, without a
 long incantation.
 
+
 Users of your modules can still use Log::Dispatch or some other
 adapter if they want to. You are not forcing your module users to use
 Log4perl.
 
+
 Btw, I'm actually fine with a Log4perl-only world. It's just that
 (currently) you need to explicitly initialize Log4perl so this might
 irritate my users if I use Log4perl in my modules. Log::Any's default
 is the nice 'null' logging so my users don't need to be aware of
 logging at all.
 
+
 =head2 How do I create extra logger objects?
 
+
 The usual way as with Log::Any:
 
+
  my $other_log = Log::Any->get_logger(category => $category);
 
+
 =head2 How do I see the Log4perl configuration that gets used?
 
+
 Set environment LOGANYAPP_DEBUG to true, and Log::Any::App will dump
 the Log4perl configuration as well as additional messages to help you
 trace how it came up to be.
 
 =head1 BUGS/TODOS
 
+
 Need to provide appropriate defaults for Windows/other OS.
 
 =head1 SEE ALSO
 
+
 L<Log::Any>
 
+
 L<Log::Log4perl>
 
 =head1 AUTHOR
